@@ -112,7 +112,7 @@ class Client:
     def users_list(self):
         """Display a list of users."""
         slack_users = self.slack.get_users()
-        print(f"Slack Usergroups [{len(slack_users)}]:")
+        print(f"Slack Users [{len(slack_users)}]:")
         for user in sorted(slack_users, key=lambda x: x["name"]):
             user_id = user["id"]
             name = user["name"]
